@@ -1,6 +1,6 @@
 ;;; consult-xref.el --- Xref integration for Consult -*- lexical-binding: t -*-
 
-;; Copyright (C) 2021-2025 Free Software Foundation, Inc.
+;; Copyright (C) 2021-2026 Free Software Foundation, Inc.
 
 ;; This file is part of GNU Emacs.
 
@@ -19,9 +19,8 @@
 
 ;;; Commentary:
 
-;; Provides Xref integration for Consult.  This is an extra package, to
-;; allow lazy loading of xref.el.  The `consult-xref' function is
-;; autoloaded.
+;; Provides the `consult-xref' function which integrates Consult into Xref.
+;; This is an extra file to allow lazy loading of xref.el.
 
 ;;; Code:
 
@@ -65,11 +64,11 @@ The fetch is stored globally such that it can be accessed by
         (funcall open))
       (let ((consult--buffer-display display))
         (funcall preview action
-                 (when-let ((loc (and cand (eq action 'preview)
-                                      (xref-item-location cand)))
-                            (type (type-of loc))
-                            ;; Only preview xrefs listed in consult-xref--preview
-                            ((memq type consult-xref--preview)))
+                 (when-let* ((loc (and cand (eq action 'preview)
+                                       (xref-item-location cand)))
+                             (type (type-of loc))
+                             ;; Only preview xrefs listed in consult-xref--preview
+                             ((memq type consult-xref--preview)))
                    (pcase type
                      ((or 'xref-file-location 'xref-etags-location)
                       (consult--marker-from-line-column
@@ -92,14 +91,14 @@ See `xref-show-xrefs-function' for the description of the
 FETCHER and ALIST arguments."
   (let* ((consult-xref--fetcher fetcher)
          (candidates (consult-xref--candidates))
-         (display (alist-get 'display-action alist))
-         (this-command #'consult-xref))
+         (display (alist-get 'display-action alist)))
     (unless candidates
       (user-error "No xref locations"))
     (xref-pop-to-location
      (if (cdr candidates)
          (consult--read
           candidates
+          :command #'consult-xref
           :prompt "Go to xref: "
           :history 'consult-xref--history
           :require-match t
@@ -108,10 +107,10 @@ FETCHER and ALIST arguments."
           :group #'consult--prefix-group
           :state
           ;; do not preview other frame
-          (when-let (fun (pcase-exhaustive display
-                           ('frame nil)
-                           ('window #'switch-to-buffer-other-window)
-                           ('nil #'switch-to-buffer)))
+          (when-let* ((fun (pcase-exhaustive display
+                             ('frame nil)
+                             ('window #'switch-to-buffer-other-window)
+                             ('nil #'switch-to-buffer))))
             (consult-xref--preview fun))
           :lookup (apply-partially #'consult--lookup-prop 'consult-xref))
        (get-text-property 0 'consult-xref (car candidates)))
